Changelog
=========

0.0.11 (2021-01-26)
-------------------

- `poll.py` can output predictions now in: csv, xml, json
- `label_image.py` can output predictions to stdout or a file and in: plaintext (current), csv, xml, json


0.0.10 (2021-01-25)
-------------------

- removed ability to split images into grid from `poll.py`
- added `tfic-export` tool to export saved model folder to Tensorflow lite model
- added support for using tflite models to `tfic-poll` and `tfic-labelimage`


0.0.9 (2020-10-21)
------------------

- `poll.py` accidentally redefined variable for resetting the session.


0.0.8 (2020-10-21)
------------------

- `poll.py` now re-initializes the Tensorflow session every X processed images to avoid
  out of memory problems (`--reset_session` option).


0.0.7 (2020-09-22)
------------------

- `poll.py` now outputs the top-X predictions with the correct labels/probability


0.0.6 (2020-09-02)
------------------

- `poll.py` in non-continuous mode now works as expected (didn't scan input directory previously)


0.0.5 (2020-08-06)
------------------

- `label_image.py`, `poll.py` and `stats.py` can now re-use the info JSON file
  generated by `retrain.py` to simplify command-line parameters (input_height,
  input_width, input_layer, output_layer, labels)
- improved help output of argument parsers: outputting description, command-line
  and default values now


0.0.4 (2020-08-04)
------------------

- `poll.py` now has new `--continuous` flag to allow for continuous or single batch predictions


0.0.3 (2020-07-28)
------------------

- `poll.py`: added ability to split images into grid of equal sized images, obtaining
  a classification for each sub-image.
- fixed license: now uses Apache 2.0 instead of MIT


0.0.2 (2019-11-14)
------------------

- added missing `MANIFEST.in`


0.0.1 (2019-11-01)
------------------

- initial release
